All of lore.kernel.org
 help / color / mirror / Atom feed
* Patch for initial CapsLock
@ 2002-12-24 18:41 Pete Zaitcev
  0 siblings, 0 replies; only message in thread
From: Pete Zaitcev @ 2002-12-24 18:41 UTC (permalink / raw)
  To: vojtech; +Cc: zaitcev, linux-kernel

Hi, Vojtech:

In 2.4.21-pre2, if Caps Lock is on and a USB keyboard is connected,
the LED will not be lit. It mostly affects KVM users like those
of IBM BladeCenter, because they "connect" keyboards all day long.
Would you be so kind to review the attached patch?

-- Pete

diff -ur -X dontdiff linux-2.4.21-pre2/drivers/input/keybdev.c linux-2.4.21-pre2-usb/drivers/input/keybdev.c
--- linux-2.4.21-pre2/drivers/input/keybdev.c	2001-10-11 09:14:32.000000000 -0700
+++ linux-2.4.21-pre2-usb/drivers/input/keybdev.c	2002-12-23 23:43:53.000000000 -0800
@@ -201,6 +201,7 @@
 	input_open_device(handle);
 
 //	printk(KERN_INFO "keybdev.c: Adding keyboard: input%d\n", dev->number);
+	kbd_refresh_leds();
 
 	return handle;
 }
@@ -222,6 +223,7 @@
 {
 	input_register_handler(&keybdev_handler);
 	kbd_ledfunc = keybdev_ledfunc;
+	kbd_refresh_leds();
 
 	if (jp_kbd_109) {
 		x86_keycodes[0xb5] = 0x73;	/* backslash, underscore */
diff -ur -X dontdiff linux-2.4.21-pre2/include/linux/kbd_kern.h linux-2.4.21-pre2-usb/include/linux/kbd_kern.h
--- linux-2.4.21-pre2/include/linux/kbd_kern.h	2002-12-19 20:22:19.000000000 -0800
+++ linux-2.4.21-pre2-usb/include/linux/kbd_kern.h	2002-12-23 23:43:31.000000000 -0800
@@ -72,6 +72,7 @@
 extern int do_poke_blanked_console;
 
 extern void (*kbd_ledfunc)(unsigned int led);
+extern void kbd_refresh_leds(void);
 
 extern void set_console(int nr);
 extern void schedule_console_callback(void);

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2002-12-24 18:32 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2002-12-24 18:41 Patch for initial CapsLock Pete Zaitcev

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.
diff -ur -X dontdiff linux-2.4.21-pre2/drivers/char/keyboard.c linux-2.4.21-pre2-usb/drivers/char/keyboard.c
--- linux-2.4.21-pre2/drivers/char/keyboard.c	2002-08-02 17:39:43.000000000 -0700
+++ linux-2.4.21-pre2-usb/drivers/char/keyboard.c	2002-12-24 10:40:48.000000000 -0800
@@ -64,6 +64,7 @@
 void (*kbd_ledfunc)(unsigned int led);
 EXPORT_SYMBOL(handle_scancode);
 EXPORT_SYMBOL(kbd_ledfunc);
+EXPORT_SYMBOL(kbd_refresh_leds);
 
 extern void ctrl_alt_del(void);
 
@@ -899,9 +900,9 @@
  * Aside from timing (which isn't really that important for
  * keyboard interrupts as they happen often), using the software
  * interrupt routines for this thing allows us to easily mask
  * this when we don't want any of the above to happen. Not yet
  * used, but this allows for easy and efficient race-condition
  * prevention later on.
  */
 static void kbd_bh(unsigned long dummy)
 {
@@ -917,6 +918,18 @@
 EXPORT_SYMBOL(keyboard_tasklet);
 DECLARE_TASKLET_DISABLED(keyboard_tasklet, kbd_bh, 0);
 
+/*
+ * This allows a newly plugged keyboard to pick the LED state.
+ * We do it in this seemindly backwards fashion to ensure proper locking.
+ * Built-in keyboard does refresh on its own.
+ */
+void kbd_refresh_leds(void)
+{
+	tasklet_disable(&keyboard_tasklet);
+	if (ledstate != 0xff && kbd_ledfunc != NULL) kbd_ledfunc(ledstate);
+	tasklet_enable(&keyboard_tasklet);
+}
+
 typedef void (pm_kbd_func) (void);
 
 pm_callback pm_kbd_request_override = NULL;
@@ -899,9 +900,9 @@
  * keyboard interrupts as they happen often), using the software
  * interrupt routines for this thing allows us to easily mask
- * this when we don't want any of the above to happen. Not yet
- * used, but this allows for easy and efficient race-condition
- * prevention later on.
+ * this when we don't want any of the above to happen.
+ * This allows for easy and efficient race-condition prevention
+ * for kbd_ledfunc => input_event(dev, EV_LED, ...) => ...
  */
 static void kbd_bh(unsigned long dummy)